Intel-GFX Archive on lore.kernel.org
 help / color / mirror / Atom feed
From: Jani Nikula <jani.nikula@intel.com>
To: intel-gfx@lists.freedesktop.org
Cc: jani.nikula@intel.com
Subject: [PATCH 3/4] drm/i915/dp: return proper error codes instead of magic -1
Date: Wed, 24 Apr 2024 14:11:00 +0300	[thread overview]
Message-ID: <20240424111101.1152824-3-jani.nikula@intel.com> (raw)
In-Reply-To: <20240424111101.1152824-1-jani.nikula@intel.com>

Use proper negative error codes intead of magic -1. Don't set a bad
example, as -1 is -EPERM.

Signed-off-by: Jani Nikula <jani.nikula@intel.com>
---
 drivers/gpu/drm/i915/display/intel_dp.c | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)

diff --git a/drivers/gpu/drm/i915/display/intel_dp.c b/drivers/gpu/drm/i915/display/intel_dp.c
index e05e25cd4a94..30c1f39ff6d6 100644
--- a/drivers/gpu/drm/i915/display/intel_dp.c
+++ b/drivers/gpu/drm/i915/display/intel_dp.c
@@ -600,7 +600,7 @@ static int intersect_rates(const int *source_rates, int source_len,
 	return k;
 }
 
 /* return index of rate in rates array, or -1 if not found */
 static int intel_dp_rate_index(const int *rates, int len, int rate)
 {
 	int i;
@@ -609,7 +609,7 @@ static int intel_dp_rate_index(const int *rates, int len, int rate)
 		if (rate == rates[i])
 			return i;
 
-	return -1;
+	return -ENOENT;
 }
 
 static void intel_dp_set_common_rates(struct intel_dp *intel_dp)
@@ -680,7 +680,7 @@ int intel_dp_get_link_train_fallback_values(struct intel_dp *intel_dp,
 	 */
 	if (intel_dp->is_mst) {
 		drm_err(&i915->drm, "Link Training Unsuccessful\n");
-		return -1;
+		return -EINVAL;
 	}
 
 	if (intel_dp_is_edp(intel_dp) && !intel_dp->use_max_params) {
@@ -717,7 +717,7 @@ int intel_dp_get_link_train_fallback_values(struct intel_dp *intel_dp,
 		intel_dp->max_link_lane_count = lane_count >> 1;
 	} else {
 		drm_err(&i915->drm, "Link Training Unsuccessful\n");
-		return -1;
+		return -EINVAL;
 	}
 
 	return 0;
@@ -600,7 +600,7 @@ static int intersect_rates(const int *source_rates, int source_len,
 }
 
-/* return index of rate in rates array, or -1 if not found */
+/* return index of rate in rates array, or -ENOENT if not found */
 static int intel_dp_rate_index(const int *rates, int len, int rate)
 {
-- 
2.39.2


  parent reply	other threads:[~2024-04-24 11:11 UTC|newest]

Thread overview: 7+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2024-04-24 11:10 [PATCH 1/4] drm/i915/dvo: return proper error code instead of magic -1 Jani Nikula
2024-04-24 11:10 ` [PATCH 2/4] drm/i915/bios: return proper error codes " Jani Nikula
2024-04-24 11:11 ` Jani Nikula [this message]
2024-04-24 11:11 ` [PATCH 4/4] drm/i915/fb: " Jani Nikula
2024-04-24 11:36 ` ✗ Fi.CI.SPARSE: warning for series starting with [1/4] drm/i915/dvo: return proper error code " Patchwork
2024-04-24 11:44 ` ✓ Fi.CI.BAT: success " Patchwork
2024-04-24 17:33 ` ✗ Fi.CI.IGT: failure " Patchwork

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20240424111101.1152824-3-jani.nikula@intel.com \
    --to=jani.nikula@intel.com \
    --cc=intel-gfx@lists.freedesktop.org \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox